$Env:CONDA_EXE = "C:\ci\conda_1548813803808\_h_env\Scripts\conda.exe"
$Env:_CONDA_ROOT = "C:\ci\conda_1548813803808\_h_env"
$Env:_CONDA_EXE = "C:\ci\conda_1548813803808\_h_env\Scripts\conda.exe"

Import-Module "$Env:_CONDA_ROOT/shell/condabin/Conda.psm1"